@@ -22,9 +22,6 @@
 #ifndef CALCTOOL_H
 #define CALCTOOL_H
 
-#include "config.h"
-#include "mp.h"
-
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -33,6 +30,10 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
+#include "config.h"
+#include "mp.h"
+#include "display.h"
+
 #define FCLOSE       (void) fclose     /* To make lint happy. */
 #define FPRINTF      (void) fprintf
 #define FPUTS        (void) fputs
@@ -60,13 +61,6 @@ enum num_type { ENG, FIX, SCI, MAXDISPMODES };
 /* Trigonometric types. */
 enum trig_type { DEG, GRAD, RAD, MAXTRIGMODES };
 
-/* Syntax mode. */
-enum syntax {
-    NPA = 0,      /* Non-precedence arithmetic */
-    EXPRS,        /* Expression with arithmetic precedence */
-    MAXSYNTAX
-};
-
 /* Abbreviations for the gcalctool keyboard */
 enum
 {
@@ -118,6 +112,10 @@ enum
     KEY_SHIFT,
     KEY_STORE, KEY_RECALL, KEY_EXCHANGE,
     KEY_SET_ACCURACY,
+    KEY_SET_BASE,
+    KEY_SET_NUMBERTYPE,
+    KEY_UNDO,
+    KEY_REDO,
     KEY_CONSTANT,
     KEY_FUNCTION,
     NKEYS
@@ -161,8 +159,6 @@ enum
 #undef FALSE
 #define FALSE          0
 
-#define UNDO_HISTORY_LENGTH 16  /* Arithmetic mode undo history length */
-
 #define MPMATH_ERR		    	20001
 
 enum button_flags {
@@ -175,47 +171,16 @@ enum button_flags {
 struct button {
     int id;
     char *symname;           /* Expression function name */
-    void (*func)();          /* Function to obey on button press. */
     enum button_flags flags; /* Misc flags */
 };
 
-/* Expression mode state */
-struct exprm_state {
-    int ans[MP_SIZE];      /* Previously calculated answer */
-    char *expression;      /* Expression entered by user */
-    int cursor;
-};
-
-/* Circular list of Arithmetic Precedence Mode states*/ 
-struct exprm_state_history {
-  unsigned int begin;
-  unsigned int end;
-  unsigned int current;
-  struct exprm_state e[UNDO_HISTORY_LENGTH];  /* Expression mode state */
-};
-
-struct ltrCalcVars {
-    int new_input;     /* New number input since last op. */
-    int noparens;      /* Count of left brackets still to be matched. */
-    int pointed;       /* Whether a decimal point has been given. */
-    
-    int cur_op;        /* Current arithmetic operation. */
-    int key_exp;       /* Set if entering exponent number. */
-    int old_cal_value; /* Previous calculation operator. */
-    int toclear;       /* Indicates if display should be cleared. */
-    char *exp_posn;    /* Position of the exponent sign. */
-};
-
 struct calcVars {                      /* Calctool variables and options. */
-    struct exprm_state_history h;      /* History of expression mode states */
-
-    int current;                       /* Current button/character pressed. */
-  
     char *appname;                     /* Application name for resources. */
     char *home;                        /* Pathname for users home directory. */
     char *progname;                    /* Name of this program. */
     
-    char display[MAXLINE];             /* Current calculator display. */
+    GCDisplay display;
+    
     const char *radix;                 /* Locale specific radix string. */
     const char *tsep;                  /* Locale specific thousands separator. */
     int tsep_count;                    /* Number of digits between separator. */
@@ -236,17 +201,12 @@ struct calcVars {                      /* Calctool variables and options. */
     enum num_type dtype;            /* Number display mode. */
     enum trig_type ttype;           /* Trig. type (deg, grad or rad). */
 
-    enum syntax syntax;             /* Calculation syntax mode */
-
     int accuracy;      /* Number of digits precision (Max 9). */
 
     int error;         /* Indicates some kind of display error. */
     int math_error;    /* Math error (used in expression mode) */
     int show_tsep;     /* Set if the thousands separator should be shown. */
     int show_zeroes;   /* Set if trailing zeroes should be shown. */
-    
-    /* Legacy left to right mode variables */
-    struct ltrCalcVars ltr;
 };
 
 typedef struct calcVars *Vars;
