@@ -281,31 +281,7 @@ static struct button_widget button_widgets[] = {
     {KEY_EXPONENTIAL,        "exponential",
     { GDK_SHIFT_MASK, 0 },
     { GDK_E,          0 }},
-
-    {KEY_E_POW_X,            "pow_e",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_braceleft,  0 }},
-
-    {KEY_10_POW_X,           "pow_10",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_braceright, 0 }},
-
-    {KEY_X_POW_Y,            "x_pow_y",
-    { GDK_SHIFT_MASK, GDK_SHIFT_MASK,  0 },
-    { GDK_caret,      GDK_asciicircum, 0 }},
-
-    {KEY_NATURAL_LOGARITHM,  "natural_logarithm",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_N,          0 }},
-
-    {KEY_LOGARITHM,          "logarithm",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_G,          0 }},
-
-    {KEY_LOGARITHM2,         "logarithm2",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_H,          0 }},
-
+    
     {KEY_FACTORIAL,          "factorial",
     { GDK_SHIFT_MASK, 0 },
     { GDK_exclam,     0 }},
@@ -314,18 +290,6 @@ static struct button_widget button_widgets[] = {
     { GDK_SHIFT_MASK, 0 },
     { GDK_question,   0 }},
 
-    {KEY_SIN,                "sine",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_K,          0 }},
-
-    {KEY_COS,                "cosine",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_J,          0 }},
-
-    {KEY_TAN,                "tangent",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_L,          0 }},
-
     {KEY_NOT,                "not",
     { GDK_SHIFT_MASK, 0 },
     { GDK_asciitilde, 0 }},
@@ -345,7 +309,43 @@ static struct button_widget button_widgets[] = {
     {KEY_XNOR,               "xnor",
     { 0,     0,     0 },
     { GDK_n, GDK_N, 0 }},
+    
+    {KEY_SIN,                "sine",
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_K,          0 }},
 
+    {KEY_COS,                "cosine",
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_J,          0 }},
+
+    {KEY_TAN,                "tangent",
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_L,          0 }},
+    
+    {KEY_NATURAL_LOGARITHM,  "natural_logarithm",
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_N,          0 }},
+
+    {KEY_E_POW_X,            "pow_e",
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_braceleft,  0 }},
+
+    {KEY_LOGARITHM,          "logarithm",
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_G,          0 }},
+    
+    {KEY_10_POW_X,           "pow_10",
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_braceright, 0 }},
+
+    {KEY_LOGARITHM2,         "logarithm2",
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_H,          0 }},
+    
+    {KEY_X_POW_Y,            "x_pow_y",
+    { GDK_SHIFT_MASK, GDK_SHIFT_MASK,  0 },
+    { GDK_caret,      GDK_asciicircum, 0 }},
+    
     {KEY_FINC_CTRM,          "finc_compounding_term",
     { 0,     0,     0 },
     { GDK_m, GDK_M, 0 }},
@@ -380,7 +380,7 @@ static struct button_widget button_widgets[] = {
 
     {KEY_FINC_TERM,          "finc_term",
     { GDK_SHIFT_MASK, 0 },
-    { GDK_T,          0 }},
+    { GDK_T,          0 }}
 };
 #define NBUTTONS (sizeof(button_widgets) / sizeof(struct button_widget))
 
@@ -1239,50 +1239,26 @@ base_cb(GtkWidget *widget)
 static void
 help_display(void)
 {
+    GdkScreen *screen;
     GError *error = NULL;
-    char *command;
-    const char *lang;
-    char *uri = NULL;
-    GdkScreen *gscreen;
-    int i;
-    
-    const char * const * langs = g_get_language_names ();
-    
-    for (i = 0; langs[i]; i++) {
-        lang = langs[i];
-        if (strchr (lang, '.')) {
-            continue;
-        }
-        
-        uri = g_build_filename(PACKAGE_DATA_DIR,
-                               "/gnome/help/gcalctool/",
-                               lang,
-                               "/gcalctool.xml",
-                               NULL);
-        
-        if (g_file_test (uri, G_FILE_TEST_EXISTS)) {
-            break;
-        }
-    }
-    
-    command = g_strconcat ("gnome-open ghelp://", uri, NULL);
-    gscreen = gdk_screen_get_default();
-    gdk_spawn_command_line_on_screen (gscreen, command, &error);
-    if (error) {
+ 
+    screen = gtk_widget_get_screen (GTK_WIDGET (X->kframe));
+    gtk_show_uri (screen, "ghelp:gcalctool", gtk_get_current_event_time (), &error);
+ 
+    if (error != NULL)
+    {
         GtkWidget *d;
+        d = gtk_message_dialog_new (GTK_WINDOW (X->kframe), 
+                                    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                    GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+                                    "%s", "Unable to open help file");
+        gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (d),
+                                                  "%s", error->message);
+        g_signal_connect (d, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+        gtk_window_present (GTK_WINDOW (d));
         
-        d = gtk_message_dialog_new(NULL,
-                           GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                           GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                           error->message);
-        gtk_dialog_run(GTK_DIALOG(d));
-        gtk_widget_destroy(d);
-        g_error_free(error);
-        error = NULL;
+        g_error_free (error);
     }
-    
-    g_free (command);
-    g_free (uri);
 }
 
 
@@ -1601,9 +1577,8 @@ request_change_mode()
     gtk_widget_show_all(dialog);
     response = gtk_dialog_run(GTK_DIALOG(dialog));
     
-    // FIXME: Save this in GConf
-    X->warn_change_mode = !gtk_toggle_button_get_active(
-                             GTK_TOGGLE_BUTTON(request_check));
+    X->warn_change_mode = !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(request_check));
+    set_boolean_resource(R_CHMODE, X->warn_change_mode);
 
     gtk_widget_destroy(dialog);
 
@@ -1806,6 +1781,16 @@ hyp_cb(GtkWidget *widget)
 }
 
 
+/*ARGSUSED*/
+void
+trig_cb(GtkWidget *widget)
+{
+    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
+        do_trigtype((enum trig_type) g_object_get_data(G_OBJECT(widget),
+                                                       "trig_mode"));
+}
+
+
 /*ARGSUSED*/
 void
 inv_cb(GtkWidget *widget)
@@ -2401,6 +2386,7 @@ create_kframe()
     CONNECT_SIGNAL(menu_item_select_cb);
     CONNECT_SIGNAL(menu_item_deselect_cb);
     CONNECT_SIGNAL(mode_radio_cb);
+    CONNECT_SIGNAL(trig_cb);
     CONNECT_SIGNAL(inv_cb);
     CONNECT_SIGNAL(hyp_cb);
     CONNECT_SIGNAL(base_cb);
@@ -2736,6 +2722,9 @@ ui_load(void)
 
     read_cfdefs();
     
+    if(!get_boolean_resource(R_CHMODE, &X->warn_change_mode))
+        X->warn_change_mode = TRUE;
+    
     /* Create main gcalctool window. */
     create_kframe();
     
@@ -2782,8 +2771,6 @@ ui_load(void)
 void
 ui_start(void)
 {
-    X->warn_change_mode = TRUE; // FIXME: Load from GConf
-    
     ui_set_base(v->base);
     ui_set_trigonometric_mode(v->ttype);
     ui_set_numeric_mode(v->dtype);
